@@ -38,7 +38,7 @@
 #include "atomicio.h"
 #include "peer.h"
 
-RCSID("$Id: flowd.c,v 1.55 2005/01/10 06:19:18 djm Exp $");
+RCSID("$Id: flowd.c,v 1.56 2005/04/28 09:02:58 djm Exp $");
 
 /* Dump unknown packet types */
 /* #define DEBUG_UNKNOWN */
@@ -1183,8 +1183,14 @@ main(int argc, char **argv)
 	SPLAY_INIT(&peers.peer_tree);
 	TAILQ_INIT(&peers.peer_list);
 
-	while ((ch = getopt(argc, argv, "dghD:f:")) != -1) {
+	while ((ch = getopt(argc, argv, "dghD:f:X:")) != -1) {
 		switch (ch) {
+		case 'X':
+			if (strcmp(optarg, "INSECURE") == 0)
+				conf.opts |= FLOWD_OPT_INSECURE;
+			else
+				logerrx("Invalid debugging option %s", optarg);
+			break;
 		case 'd':
 			conf.opts |= FLOWD_OPT_DONT_FORK;
 			conf.opts |= FLOWD_OPT_VERBOSE;
